@@ -49,7 +49,6 @@ function formatComment(comment) {
     }
     return item.lines.map(function (line) {
       return line.replace(/\t/g, '    ')
-        .replace(/ /g, '&nbsp;')
         .replace(/`(.+?)`/g, function (match, code) {
           return '<code>' + code + '</code>'
         })
@@ -135,6 +134,8 @@ function goToAnchor() {
     if (anchor.parent().is('summary')) {
       // 锚点是模块，那么直接滚动到其位置
       anchor.get(0).scrollIntoView()
+      // 然后展开其模块节点
+      anchor.parent().parent().prop('open', 'open')
       break
     }
     // 锚点是路由，那么展开其所在模块，然后滚动到其位置
@@ -341,6 +342,8 @@ function renderArg(arg, editable) {
       argType = 'file'
     } else if (argType === 'list') {
       argType = 'array'
+    } else if (argType === 'dict') {
+      argType = 'object'
     }
   } else {
     argType = '-'
@@ -387,7 +390,10 @@ function renderArgs(args, editable, append) {
       ]))
     ])
   }
+  return renderArgRows(args, editable, append)
+}
 
+function renderArgRows(args, editable, append) {
   var rows = args.filter(function (arg) {
     // 编辑时不渲染 可变参数
     return !editable || !arg.is_variable
